@@ -1,5 +1,6 @@
 import copy
 
+import pymongo.errors
 from motor.motor_asyncio import (
     AsyncIOMotorClient,
     AsyncIOMotorCollection,
@@ -127,7 +128,10 @@ class MDocument(metaclass=MetaDocument):
         query = args[0]
         cls.Model.validate(query, pre_insert=True)
         cls.Model.pop_optional_none(query)
-        await cls.collection.insert_one(*args, **kwargs)
+        try:
+            await cls.collection.insert_one(*args, **kwargs)
+        except pymongo.errors.DuplicateKeyError:
+            raise cls.DuplicateError()
         return cls(query)
 
     @classmethod
