@@ -83,7 +83,7 @@ class Model:
         return query
 
     @classmethod
-    def validate(cls, document: typing.Union["MDocument", dict]):
+    def validate(cls, document: typing.Union["MDocument", dict], pre_insert=False):
         """Validates that fields are present and have correct types."""
 
         from mdocument.document import MDocument
@@ -102,6 +102,8 @@ class Model:
         for field_name, field in cls.fields().items():
             doc_field_value = doc.get(field_name)
             if doc_field_value is None and not field.optional:
+                if field.is_primary and pre_insert:
+                    continue
                 raise exceptions.RequiredFieldMissing(field_name)
             elif doc_field_value is None and field.optional:
                 continue
